[zorg] r281511 - [zorg] Don't exclude compiler-rt runtimes from build.py artifacts

Vedant Kumar via llvm-commits llvm-commits at lists.llvm.org
Wed Sep 14 10:44:05 PDT 2016


Author: vedantk
Date: Wed Sep 14 12:44:04 2016
New Revision: 281511

URL: http://llvm.org/viewvc/llvm-project?rev=281511&view=rev
Log:
[zorg] Don't exclude compiler-rt runtimes from build.py artifacts

build.py tars up the cmake build products to create an artifact, but it
excludes all .a files. That means that the resulting compiler artifacts
aren't prepped with any compiler-rt runtimes.

Be more selective about the .a files we exclude.

Differential Revision: https://reviews.llvm.org/D24539

Modified:
    zorg/trunk/zorg/jenkins/build.py

Modified: zorg/trunk/zorg/jenkins/build.py
URL: http://llvm.org/viewvc/llvm-project/zorg/trunk/zorg/jenkins/build.py?rev=281511&r1=281510&r2=281511&view=diff
==============================================================================
--- zorg/trunk/zorg/jenkins/build.py (original)
+++ zorg/trunk/zorg/jenkins/build.py Wed Sep 14 12:44:04 2016
@@ -672,8 +672,10 @@ def build_upload_artifact():
         prop_fd.write("LLVM_REV={}\n".format(conf.svn_rev))
         prop_fd.write("ARTIFACT={}\n".format(new_url))
 
-    # The .a's are big and we don't need them later. Drop them.
-    tar = ["tar", "zcvf", "../" + artifact_name, '--exclude=*.a',  "."]
+    # The .a's are big and we don't need them later. Drop the LLVM and clang
+    # libraries, but keep the libraries from compiler-rt.
+    tar = ["tar", "zcvf", "../" + artifact_name, "--exclude=*libLLVM*.a",
+           "--exclude=*libclang[A-Z]*.a", "."]
 
     run_cmd(conf.installdir(), tar)
 




More information about the llvm-commits mailing list